==> qabc_1.9.1.orig.tar.gz: qabc-1.9.1/qabc_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>AbcMainWindow</name>
    <message>
        <location filename="AbcMainWindow.cpp" line="16"/>
        <source>QAbc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="AbcMainWindow.cpp" line="22"/>
        <source>Idle</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditTabWidget</name>
    <message>
        <location filename="EditTabWidget.cpp" line="77"/>
        <source>Really close?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="EditTabWidget.cpp" line="78"/>
        <source>Current score not saved!
Close this score anyway?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditVBoxLayout</name>
    <message>
        <location filename="EditVBoxLayout.cpp" line="33"/>
        <source>X:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="176"/>
        <source>Failed to start program: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="177"/>
        <source>Please check settings.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="358"/>
        <source>Generating MIDI for playing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="363"/>
        <source>Stopping synthesis.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="374"/>
        <source>Error during MIDI generation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="380"/>
        <source>MIDI generation finished.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="394"/>
        <source>Starting synthesis...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="404"/>
        <source>Synthesis finished.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="421"/>
        <source>Generating score...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="444"/>
        <source>Refresh &amp;view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="449"/>
        <source>Error during score generation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="453"/>
        <source>Score generated.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="471"/>
        <source>Starting viewer...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="480"/>
        <source>Viewer closed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="193"/>
        <location filename="EditVBoxLayout.cpp" line="487"/>
        <source>&amp;View score</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditorPrefDialog</name>
    <message>
        <location filename="editorprefdialog.cpp" line="22"/>
        <source>Editor settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="28"/>
        <source>Font enlargement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="40"/>
        <source>Highlight current line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="51"/>
        <source>Header color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="52"/>
        <source>Comment color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="53"/>
        <source>Extra instruction color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="54"/>
        <source>Measure bar color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="55"/>
        <source>Decoration color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="56"/>
        <source>Guitar chord color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="57"/>
        <source>Lyric color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HelpMenu</name>
    <message>
        <location filename="HelpMenu.cpp" line="19"/>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="HelpMenu.cpp" line="21"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="HelpMenu.cpp" line="24"/>
        <source>About Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="HelpMenu.cpp" line="38"/>
        <location filename="HelpMenu.cpp" line="44"/>
        <source>ABC score editor</source>
        <oldsource>Abc score editor</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="HelpMenu.cpp" line="38"/>
        <source>Copyright © 2020 Benoît Rouits &lt;brouits@free.fr&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="HelpMenu.cpp" line="38"/>
        <source>
QAbc version </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PlayPushButton</name>
    <message>
        <location filename="PlayPushButton.cpp" line="17"/>
        <location filename="PlayPushButton.cpp" line="31"/>
        <source>&amp;Play</source>
        <oldsource>Play</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PlayPushButton.cpp" line="28"/>
        <source>Sto&amp;p</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PreferencesMenu</name>
    <message>
        <location filename="PreferencesMenu.cpp" line="21"/>
        <source>Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="24"/>
        <source>MIDI Generator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="27"/>
        <source>MIDI Synthesizer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="30"/>
        <source>Score generator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="33"/>
        <source>Score viewer</source>
        <oldsource>Viewer</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="36"/>
        <source>Editor settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="39"/>
        <source>Reset to defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="63"/>
        <location filename="PreferencesMenu.cpp" line="65"/>
        <source>Compiler preference</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="63"/>
        <location filename="PreferencesMenu.cpp" line="65"/>
        <source>Compiler:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="123"/>
        <location filename="PreferencesMenu.cpp" line="125"/>
        <source>PS viewer preference</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="123"/>
        <location filename="PreferencesMenu.cpp" line="125"/>
        <source>PS Viewer:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="83"/>
        <location filename="PreferencesMenu.cpp" line="85"/>
        <source>Player preference</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="83"/>
        <location filename="PreferencesMenu.cpp" line="85"/>
        <source>Player:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="103"/>
        <location filename="PreferencesMenu.cpp" line="105"/>
        <source>Synth preference</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="103"/>
        <location filename="PreferencesMenu.cpp" line="105"/>
        <source>Synth:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RunPushButton</name>
    <message>
        <location filename="RunPushButton.cpp" line="16"/>
        <source>&amp;View score</source>
        <oldsource>Generate score</oldsource>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScoreMenu</name>
    <message>
        <location filename="ScoreMenu.cpp" line="26"/>
        <source>Score</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="29"/>
        <source>New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="33"/>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="42"/>
        <source>Recently opened</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="49"/>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="52"/>
        <source>Save as</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="56"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="60"/>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="86"/>
        <source>Really quit?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="88"/>
        <source> score(s) not saved.
Do you want to quit anyway?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="108"/>
        <source>Open ABC Score</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="108"/>
        <location filename="ScoreMenu.cpp" line="236"/>
        <source>ABC score (*.abc)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="190"/>
        <location filename="ScoreMenu.cpp" line="207"/>
        <location filename="ScoreMenu.cpp" line="222"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="190"/>
        <source>Could not open score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="207"/>
        <source>Could not save an untitled ABC score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="220"/>
        <source>Score saved.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="236"/>
        <source>Save ABC score</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="222"/>
        <source>Could not save ABC score!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ViewVBoxLayout</name>
    <message>
        <location filename="ViewVBoxLayout.cpp" line="17"/>
        <source>Clear log</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="main.cpp" line="46"/>
        <source>ABC score file to work on.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qabc_1.13.orig.tar.gz: qabc-1.13/qabc_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>AbcMainWindow</name>
    <message>
        <location filename="AbcMainWindow.cpp" line="16"/>
        <source>QAbc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="AbcMainWindow.cpp" line="22"/>
        <source>Idle</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AbcPlainTextEdit</name>
    <message>
        <location filename="AbcPlainTextEdit.cpp" line="70"/>
        <location filename="AbcPlainTextEdit.cpp" line="209"/>
        <source>Find...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="AbcPlainTextEdit.cpp" line="76"/>
        <location filename="AbcPlainTextEdit.cpp" line="223"/>
        <source>Find forward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="AbcPlainTextEdit.cpp" line="82"/>
        <location filename="AbcPlainTextEdit.cpp" line="237"/>
        <source>Find backward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="AbcPlainTextEdit.cpp" line="209"/>
        <location filename="AbcPlainTextEdit.cpp" line="223"/>
        <location filename="AbcPlainTextEdit.cpp" line="237"/>
        <source>Text:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditTabWidget</name>
    <message>
        <location filename="EditTabWidget.cpp" line="78"/>
        <source>Really close?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="EditTabWidget.cpp" line="79"/>
        <source>Current score not saved!
Close this score anyway?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditVBoxLayout</name>
    <message>
        <location filename="EditVBoxLayout.cpp" line="32"/>
        <source>X:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="214"/>
        <source>Failed to start program: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="215"/>
        <source>Please check settings.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="402"/>
        <source>Generating MIDI for playing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="407"/>
        <source>Stopping synthesis.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="418"/>
        <source>Error during MIDI generation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="424"/>
        <source>MIDI generation finished.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="440"/>
        <source>Starting synthesis...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="450"/>
        <source>Synthesis finished.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="467"/>
        <source>Generating score...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="493"/>
        <source>Refresh &amp;view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="498"/>
        <source>Error during score generation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="502"/>
        <source>Score generated.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="523"/>
        <source>Starting viewer...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="532"/>
        <source>Viewer closed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="231"/>
        <location filename="EditVBoxLayout.cpp" line="539"/>
        <source>&amp;View score</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditorPrefDialog</name>
    <message>
        <location filename="editorprefdialog.cpp" line="22"/>
        <source>Editor settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="28"/>
        <source>These settings will be applied on newly opened tabs only.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="32"/>
        <source>Base font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="46"/>
        <source>Font enlargement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="59"/>
        <source>Highlight current line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="71"/>
        <source>Header color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="72"/>
        <source>Comment color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="73"/>
        <source>Extra instruction color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="74"/>
        <source>Measure bar color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="75"/>
        <source>Decoration color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="76"/>
        <source>Guitar chord color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="77"/>
        <source>Lyric color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HelpMenu</name>
    <message>
        <location filename="HelpMenu.cpp" line="19"/>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="HelpMenu.cpp" line="21"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="HelpMenu.cpp" line="22"/>
        <source>About Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="HelpMenu.cpp" line="32"/>
        <location filename="HelpMenu.cpp" line="38"/>
        <source>ABC score editor</source>
        <oldsource>Abc score editor</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="HelpMenu.cpp" line="32"/>
        <source>Copyright © 2020 Benoît Rouits &lt;brouits@free.fr&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="HelpMenu.cpp" line="32"/>
        <source>
QAbc version </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PlayPushButton</name>
    <message>
        <location filename="PlayPushButton.cpp" line="17"/>
        <location filename="PlayPushButton.cpp" line="31"/>
        <source>&amp;Play</source>
        <oldsource>Play</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PlayPushButton.cpp" line="28"/>
        <source>Sto&amp;p</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PreferencesMenu</name>
    <message>
        <location filename="PreferencesMenu.cpp" line="21"/>
        <source>Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="24"/>
        <source>MIDI Generator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="25"/>
        <source>MIDI Synthesizer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="26"/>
        <source>Score generator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="27"/>
        <source>Score viewer</source>
        <oldsource>Viewer</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="28"/>
        <source>Editor settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="29"/>
        <source>Reset to defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="45"/>
        <location filename="PreferencesMenu.cpp" line="47"/>
        <source>Compiler preference</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="45"/>
        <location filename="PreferencesMenu.cpp" line="47"/>
        <source>Compiler:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="105"/>
        <location filename="PreferencesMenu.cpp" line="107"/>
        <source>PS viewer preference</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="105"/>
        <location filename="PreferencesMenu.cpp" line="107"/>
        <source>PS Viewer:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="65"/>
        <location filename="PreferencesMenu.cpp" line="67"/>
        <source>Player preference</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="65"/>
        <location filename="PreferencesMenu.cpp" line="67"/>
        <source>Player:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="85"/>
        <location filename="PreferencesMenu.cpp" line="87"/>
        <source>Synth preference</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="85"/>
        <location filename="PreferencesMenu.cpp" line="87"/>
        <source>Synth:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RunPushButton</name>
    <message>
        <location filename="RunPushButton.cpp" line="16"/>
        <source>&amp;View score</source>
        <oldsource>Generate score</oldsource>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScoreMenu</name>
    <message>
        <location filename="ScoreMenu.cpp" line="26"/>
        <source>Score</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="29"/>
        <location filename="ScoreMenu.cpp" line="32"/>
        <source>New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="30"/>
        <location filename="ScoreMenu.cpp" line="33"/>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="42"/>
        <source>Recently opened</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="49"/>
        <location filename="ScoreMenu.cpp" line="54"/>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="50"/>
        <location filename="ScoreMenu.cpp" line="55"/>
        <source>Save as</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="51"/>
        <location filename="ScoreMenu.cpp" line="56"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="52"/>
        <location filename="ScoreMenu.cpp" line="57"/>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="76"/>
        <source>Really quit?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="78"/>
        <source> score(s) not saved.
Do you want to quit anyway?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="98"/>
        <source>Open ABC Score</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="98"/>
        <location filename="ScoreMenu.cpp" line="228"/>
        <source>ABC score (*.abc)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="180"/>
        <location filename="ScoreMenu.cpp" line="197"/>
        <location filename="ScoreMenu.cpp" line="214"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="180"/>
        <source>Could not open score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="197"/>
        <source>Could not save an untitled ABC score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="211"/>
        <source>Score saved.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="228"/>
        <source>Save ABC score</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="214"/>
        <source>Could not save ABC score!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ViewVBoxLayout</name>
    <message>
        <location filename="ViewVBoxLayout.cpp" line="17"/>
        <source>Clear log</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="main.cpp" line="46"/>
        <source>ABC score file to work on.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
